@@ -15,6 +15,7 @@ from inspect import getmembers
 
 from torch import nn
 
+from flash.core.data.utils import _STAGES_PREFIX
 from flash.core.registry import FlashRegistry
 from flash.core.utilities.imports import _ICEVISION_AVAILABLE
 
@@ -22,14 +23,20 @@ if _ICEVISION_AVAILABLE:
     from icevision.backbones import BackboneConfig
 
 
-def icevision_model_adapter(model_type):
-    class IceVisionModelAdapter(model_type.lightning.ModelAdapter):
-        def log(self, name, value, **kwargs):
-            if "prog_bar" not in kwargs:
-                kwargs["prog_bar"] = True
-            return super().log(name.split("/")[-1], value, **kwargs)
+def _log_with_name_and_prog_bar_override(self, name, value, **kwargs):
+    if "prog_bar" not in kwargs:
+        kwargs["prog_bar"] = True
+    metric = name.split("/")[-1]
+    metric = f"{_STAGES_PREFIX[self.trainer.state.stage]}_{metric}"
+    return self._original_log(metric, value, **kwargs)
 
-    return IceVisionModelAdapter
+
+def icevision_model_adapter(model_type):
+    adapter = model_type.lightning.ModelAdapter
+    if not hasattr(adapter, "_original_log"):
+        adapter._original_log = adapter.log
+        adapter.log = _log_with_name_and_prog_bar_override
+    return adapter
 
 
 def load_icevision(adapter, model_type, backbone, num_classes, **kwargs):
@@ -40,6 +47,11 @@ def load_icevision(adapter, model_type, backbone, num_classes, **kwargs):
     for i, param in enumerate(params):
         backbone.register_parameter(f"backbone_{i}", param)
 
+    # Param groups cause a pickle error so we remove them
+    del model.param_groups
+    if hasattr(model, "backbone") and hasattr(model.backbone, "param_groups"):
+        del model.backbone.param_groups
+
     return model_type, model, adapter(model_type), backbone
 
 
@@ -56,6 +68,10 @@ def get_backbones(model_type):
     _BACKBONES = FlashRegistry("backbones")
 
     for backbone_name, backbone_config in getmembers(model_type.backbones, lambda x: isinstance(x, BackboneConfig)):
+        # Only torchvision backbones with an FPN are supported
+        if "torchvision" in model_type.__name__ and "fpn" not in backbone_name:
+            continue
+
         _BACKBONES(
             backbone_config,
             name=backbone_name,
