@@ -17,8 +17,8 @@ import torch
 import torch.nn.functional as F
 import torchmetrics
 
+from flash.core.adapter import AdapterTask
 from flash.core.model import Task
-from flash.core.utilities.types import OUTPUT_TYPE
 
 
 class RegressionMixin:
@@ -42,7 +42,6 @@ class RegressionTask(Task, RegressionMixin):
         *args,
         loss_fn: Optional[Callable] = None,
         metrics: Union[torchmetrics.Metric, Mapping, Sequence, None] = None,
-        output: OUTPUT_TYPE = None,
         **kwargs,
     ) -> None:
 
@@ -52,6 +51,23 @@ class RegressionTask(Task, RegressionMixin):
             *args,
             loss_fn=loss_fn,
             metrics=metrics,
-            output=output,
+            **kwargs,
+        )
+
+
+class RegressionAdapterTask(AdapterTask, RegressionMixin):
+    def __init__(
+        self,
+        *args,
+        loss_fn: Optional[Callable] = None,
+        metrics: Union[torchmetrics.Metric, Mapping, Sequence, None] = None,
+        **kwargs,
+    ) -> None:
+        metrics, loss_fn = RegressionMixin._build(loss_fn, metrics)
+
+        super().__init__(
+            *args,
+            loss_fn=loss_fn,
+            metrics=metrics,
             **kwargs,
         )
