@@ -23,9 +23,10 @@ import pytorch_lightning as pl
 from jsonargparse import ArgumentParser
 from jsonargparse.signatures import get_class_signature_functions
 from pytorch_lightning import LightningModule, Trainer
+from pytorch_lightning.utilities.model_helpers import is_overridden
 
 import flash
-from flash.core.data.data_source import DefaultDataSources
+from flash.core.data.data_module import DataModule
 from flash.core.utilities.lightning_cli import (
     class_from_function,
     LightningArgumentParser,
@@ -74,6 +75,14 @@ def drop_kwargs(func):
     return wrapper
 
 
+def get_kwarg_name(func) -> Optional[str]:
+    sig = signature(func)
+    var_kwargs = [p for p in sig.parameters.values() if p.kind == p.VAR_KEYWORD]
+    if len(var_kwargs) == 1:
+        return var_kwargs[0].name
+    return None
+
+
 def make_args_optional(cls, args: Set[str]):
     @wraps(cls)
     def wrapper(*args, **kwargs):
@@ -107,6 +116,11 @@ def get_overlapping_args(func_a, func_b) -> Set[str]:
 
 
 class FlashCLI(LightningCLI):
+
+    datamodule: DataModule
+    config_init: Namespace
+    model: LightningModule
+
     def __init__(
         self,
         model_class: Type[pl.LightningModule],
@@ -126,9 +140,9 @@ class FlashCLI(LightningCLI):
             datamodule_class: The :class:`~flash.data.data_module.DataModule` class.
             trainer_class: An optional extension of the :class:`pytorch_lightning.Trainer` class.
             trainer_fn: The trainer function to run.
-            datasource: Use this if your ``DataModule`` is created using a classmethod. Any of:
+            input: Use this if your ``DataModule`` is created using a classmethod. Any of:
                 - ``None``. The ``datamodule_class.__init__`` signature will be used.
-                - ``str``. One of :class:`~flash.data.data_source.DefaultDataSources`. This will use the signature of
+                - ``str``. One of :class:`~flash.data.io.input.InputFormat`. This will use the signature of
                     the corresponding ``DataModule.from_*`` method.
                 - ``Callable``. A custom method.
             kwargs: See the parent arguments
@@ -180,15 +194,14 @@ class FlashCLI(LightningCLI):
     def add_arguments_to_parser(self, parser) -> None:
         subcommands = parser.add_subcommands()
 
-        data_sources = self.local_datamodule_class.preprocess_cls().available_data_sources()
-
-        for data_source in data_sources:
-            if isinstance(data_source, DefaultDataSources):
-                data_source = data_source.value
-            if hasattr(self.local_datamodule_class, f"from_{data_source}"):
-                self.add_subcommand_from_function(
-                    subcommands, getattr(self.local_datamodule_class, f"from_{data_source}")
-                )
+        for function in vars(self.local_datamodule_class).keys():
+            if not function.startswith("from"):
+                continue
+            if (
+                hasattr(DataModule, function) and is_overridden(function, self.local_datamodule_class, DataModule)
+            ) or not hasattr(DataModule, function):
+                if getattr(self.local_datamodule_class, function, None) is not None:
+                    self.add_subcommand_from_function(subcommands, getattr(self.local_datamodule_class, function))
 
         for datamodule_builder in self.additional_datamodule_builders:
             self.add_subcommand_from_function(subcommands, datamodule_builder)
@@ -200,12 +213,28 @@ class FlashCLI(LightningCLI):
 
     def add_subcommand_from_function(self, subcommands, function, function_name=None):
         subcommand = ArgumentParser()
-        datamodule_function = class_from_function(drop_kwargs(function))
-        preprocess_function = class_from_function(drop_kwargs(self.local_datamodule_class.preprocess_cls))
-        subcommand.add_class_arguments(datamodule_function, fail_untyped=False)
-        subcommand.add_class_arguments(
-            preprocess_function, fail_untyped=False, skip=get_overlapping_args(datamodule_function, preprocess_function)
-        )
+        if get_kwarg_name(function) == "data_module_kwargs":
+            datamodule_function = class_from_function(function, return_type=self.local_datamodule_class)
+            subcommand.add_class_arguments(
+                datamodule_function,
+                fail_untyped=False,
+                skip={
+                    "self",
+                    "train_dataset",
+                    "val_dataset",
+                    "test_dataset",
+                    "predict_dataset",
+                    "train_input",
+                    "val_input",
+                    "test_input",
+                    "predict_input",
+                    "input",
+                    "input_transform",
+                },
+            )
+        else:
+            datamodule_function = class_from_function(drop_kwargs(function), return_type=self.local_datamodule_class)
+            subcommand.add_class_arguments(datamodule_function, fail_untyped=False)
         subcommand_name = function_name or function.__name__
         subcommands.add_subcommand(subcommand_name, subcommand)
         self._subcommand_builders[subcommand_name] = function
