@@ -14,9 +14,10 @@
 import functools
 import importlib
 import operator
+import os
 import types
 from importlib.util import find_spec
-from typing import List, Union
+from typing import List, Tuple, Union
 
 from pkg_resources import DistributionNotFound
 
@@ -70,7 +71,7 @@ _PL_AVAILABLE = _module_available("pytorch_lightning")
 _BOLTS_AVAILABLE = _module_available("pl_bolts") and _compare_version("torch", operator.lt, "1.9.0")
 _PANDAS_AVAILABLE = _module_available("pandas")
 _SKLEARN_AVAILABLE = _module_available("sklearn")
-_TABNET_AVAILABLE = _module_available("pytorch_tabnet")
+_PYTORCHTABULAR_AVAILABLE = _module_available("pytorch_tabular")
 _FORECASTING_AVAILABLE = _module_available("pytorch_forecasting")
 _KORNIA_AVAILABLE = _module_available("kornia")
 _COCO_AVAILABLE = _module_available("pycocotools")
@@ -121,9 +122,12 @@ else:
 if Version:
     _TORCHVISION_GREATER_EQUAL_0_9 = _compare_version("torchvision", operator.ge, "0.9.0")
     _PL_GREATER_EQUAL_1_4_3 = _compare_version("pytorch_lightning", operator.ge, "1.4.3")
+    _PL_GREATER_EQUAL_1_4_0 = _compare_version("pytorch_lightning", operator.ge, "1.4.0")
     _PL_GREATER_EQUAL_1_5_0 = _compare_version("pytorch_lightning", operator.ge, "1.5.0")
+    _PL_GREATER_EQUAL_1_6_0 = _compare_version("pytorch_lightning", operator.ge, "1.6.0rc0")
     _PANDAS_GREATER_EQUAL_1_3_0 = _compare_version("pandas", operator.ge, "1.3.0")
     _ICEVISION_GREATER_EQUAL_0_11_0 = _compare_version("icevision", operator.ge, "0.11.0")
+    _TM_GREATER_EQUAL_0_7_0 = _compare_version("torchmetrics", operator.ge, "0.7.0")
 
 _TEXT_AVAILABLE = all(
     [
@@ -134,7 +138,7 @@ _TEXT_AVAILABLE = all(
         _SENTENCE_TRANSFORMERS_AVAILABLE,
     ]
 )
-_TABULAR_AVAILABLE = _TABNET_AVAILABLE and _PANDAS_AVAILABLE and _FORECASTING_AVAILABLE
+_TABULAR_AVAILABLE = _PANDAS_AVAILABLE and _FORECASTING_AVAILABLE and _PYTORCHTABULAR_AVAILABLE
 _VIDEO_AVAILABLE = _TORCHVISION_AVAILABLE and _PIL_AVAILABLE and _PYTORCHVIDEO_AVAILABLE and _KORNIA_AVAILABLE
 _IMAGE_AVAILABLE = all(
     [
@@ -165,7 +169,7 @@ _EXTRAS_AVAILABLE = {
 }
 
 
-def requires(module_paths: Union[str, List]):
+def requires(module_paths: Union[str, Tuple[bool, str], List[Union[str, Tuple[bool, str]]]]):
 
     if not isinstance(module_paths, list):
         module_paths = [module_paths]
@@ -175,14 +179,18 @@ def requires(module_paths: Union[str, List]):
         extras = []
         modules = []
         for module_path in module_paths:
-            if module_path in _EXTRAS_AVAILABLE:
-                extras.append(module_path)
-                if not _EXTRAS_AVAILABLE[module_path]:
-                    available = False
+            if isinstance(module_path, str):
+                if module_path in _EXTRAS_AVAILABLE:
+                    extras.append(module_path)
+                    if not _EXTRAS_AVAILABLE[module_path]:
+                        available = False
+                else:
+                    modules.append(module_path)
+                    if not _module_available(module_path):
+                        available = False
             else:
+                available, module_path = module_path
                 modules.append(module_path)
-                if not _module_available(module_path):
-                    available = False
 
         if not available:
             modules = [f"'{module}'" for module in modules]
@@ -266,3 +274,29 @@ class LazyModule(types.ModuleType):
         # Update this object's dict so that attribute references are efficient
         # (__getattr__ is only called on lookups that fail)
         self.__dict__.update(module.__dict__)
+
+
+# Global variables used for testing purposes (e.g. to only run doctests in the correct CI job)
+_IMAGE_TESTING = _IMAGE_AVAILABLE
+_IMAGE_EXTRAS_TESTING = False  # Not for normal use
+_VIDEO_TESTING = _VIDEO_AVAILABLE
+_VIDEO_EXTRAS_TESTING = False  # Not for normal use
+_TABULAR_TESTING = _TABULAR_AVAILABLE
+_TEXT_TESTING = _TEXT_AVAILABLE
+_SERVE_TESTING = _SERVE_AVAILABLE
+_POINTCLOUD_TESTING = _POINTCLOUD_AVAILABLE
+_GRAPH_TESTING = _GRAPH_AVAILABLE
+_AUDIO_TESTING = _AUDIO_AVAILABLE
+
+if "FLASH_TEST_TOPIC" in os.environ:
+    topic = os.environ["FLASH_TEST_TOPIC"]
+    _IMAGE_TESTING = topic == "image"
+    _IMAGE_EXTRAS_TESTING = topic == "image,image_extras" or topic == "icevision" or topic == "vissl"
+    _VIDEO_TESTING = topic == "video"
+    _VIDEO_EXTRAS_TESTING = topic == "video,video_extras"
+    _TABULAR_TESTING = topic == "tabular"
+    _TEXT_TESTING = topic == "text"
+    _SERVE_TESTING = topic == "serve"
+    _POINTCLOUD_TESTING = topic == "pointcloud"
+    _GRAPH_TESTING = topic == "graph"
+    _AUDIO_TESTING = topic == "audio"
