@@ -14,18 +14,17 @@
 import base64
 from io import BytesIO
 from pathlib import Path
-from typing import Any, Dict, List, TYPE_CHECKING
+from typing import Any, Dict, List
 
 import numpy as np
 import torch
 
 import flash
-from flash.core.data.io.input import DataKeys, Input
-from flash.core.data.process import Deserializer
+from flash.core.data.io.input import DataKeys, Input, ServeInput
 from flash.core.data.utilities.paths import filter_valid_files, has_file_allowed_extension, PATH_TYPE
 from flash.core.data.utilities.samples import to_samples
 from flash.core.data.utils import image_default_loader
-from flash.core.utilities.imports import _FIFTYONE_AVAILABLE, _TORCHVISION_AVAILABLE, Image, lazy_import, requires
+from flash.core.utilities.imports import _TORCHVISION_AVAILABLE, Image, requires
 
 if _TORCHVISION_AVAILABLE:
     from torchvision.datasets.folder import IMG_EXTENSIONS
@@ -33,14 +32,6 @@ if _TORCHVISION_AVAILABLE:
 else:
     IMG_EXTENSIONS = (".jpg", ".jpeg", ".png", ".ppm", ".bmp", ".pgm", ".tif", ".tiff", ".webp")
 
-SampleCollection = None
-if _FIFTYONE_AVAILABLE:
-    fol = lazy_import("fiftyone.core.labels")
-    if TYPE_CHECKING:
-        pass
-else:
-    fol = None
-
 NP_EXTENSIONS = (".npy",)
 
 
@@ -57,7 +48,7 @@ def image_loader(filepath: str):
     return img
 
 
-class ImageDeserializer(Deserializer):
+class ImageDeserializer(ServeInput):
     @requires("image")
     def serve_load_sample(self, data: str) -> Dict:
         encoded_with_padding = (data + "===").encode("ascii")
