@@ -16,11 +16,11 @@ from typing import Any, cast, List, NoReturn, Optional, Sequence, Tuple, Union
 import torch
 from torch import nn
 
-from flash.core.data.data_source import DefaultDataKeys
+from flash.core.data.io.input import DataKeys
 from flash.core.model import Task
 from flash.core.registry import FlashRegistry
 from flash.core.utilities.imports import _IMAGE_AVAILABLE
-from flash.core.utilities.types import LR_SCHEDULER_TYPE, OPTIMIZER_TYPE, SERIALIZER_TYPE
+from flash.core.utilities.types import LR_SCHEDULER_TYPE, OPTIMIZER_TYPE
 from flash.image.style_transfer import STYLE_TRANSFER_BACKBONES
 
 if _IMAGE_AVAILABLE:
@@ -61,7 +61,6 @@ class StyleTransfer(Task):
         optimizer: Optimizer to use for training.
         lr_scheduler: The LR scheduler to use during training.
         learning_rate: Learning rate to use for training, defaults to ``1e-3``.
-        serializer: The :class:`~flash.core.data.process.Serializer` to use when serializing prediction outputs.
     """
 
     backbones: FlashRegistry = STYLE_TRANSFER_BACKBONES
@@ -79,8 +78,7 @@ class StyleTransfer(Task):
         style_weight: float = 1e10,
         optimizer: OPTIMIZER_TYPE = "Adam",
         lr_scheduler: LR_SCHEDULER_TYPE = None,
-        learning_rate: float = 1e-3,
-        serializer: SERIALIZER_TYPE = None,
+        learning_rate: Optional[float] = None,
     ):
         self.save_hyperparameters(ignore="style_image")
 
@@ -110,7 +108,6 @@ class StyleTransfer(Task):
             optimizer=optimizer,
             lr_scheduler=lr_scheduler,
             learning_rate=learning_rate,
-            serializer=serializer,
         )
 
         self.perceptual_loss = perceptual_loss
@@ -153,7 +150,7 @@ class StyleTransfer(Task):
         return loss.PerceptualLoss(content_loss, style_loss)
 
     def training_step(self, batch: Any, batch_idx: int) -> Any:
-        input_image = batch[DefaultDataKeys.INPUT]
+        input_image = batch[DataKeys.INPUT]
         self.perceptual_loss.set_content_image(input_image)
         output_image = self(input_image)
         return self.perceptual_loss(output_image).total()
@@ -165,5 +162,5 @@ class StyleTransfer(Task):
         raise_not_supported("test")
 
     def predict_step(self, batch: Any, batch_idx: int, dataloader_idx: int = 0) -> Any:
-        input_image = batch[DefaultDataKeys.INPUT]
+        input_image = batch[DataKeys.INPUT]
         return self(input_image)
