@@ -11,15 +11,15 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-from typing import Any, Dict, Optional, Tuple, Union
+from typing import Any, Dict, List, Optional, Tuple, Union
 
 import torch
 from torch import nn
 
-from flash.core.classification import ClassificationTask, Labels
-from flash.core.data.data_source import DefaultDataKeys
+from flash.core.classification import ClassificationTask
+from flash.core.data.io.input import DataKeys
 from flash.core.registry import FlashRegistry
-from flash.core.utilities.types import LOSS_FN_TYPE, LR_SCHEDULER_TYPE, METRICS_TYPE, OPTIMIZER_TYPE, SERIALIZER_TYPE
+from flash.core.utilities.types import LOSS_FN_TYPE, LR_SCHEDULER_TYPE, METRICS_TYPE, OPTIMIZER_TYPE
 from flash.template.classification.backbones import TEMPLATE_BACKBONES
 
 
@@ -40,7 +40,6 @@ class TemplateSKLearnClassifier(ClassificationTask):
             by the :class:`~flash.core.classification.ClassificationTask` depending on the ``multi_label`` argument.
         learning_rate: The learning rate for the optimizer.
         multi_label: If ``True``, this will be treated as a multi-label classification problem.
-        serializer: The :class:`~flash.core.data.process.Serializer` to use for prediction outputs.
     """
 
     backbones: FlashRegistry = TEMPLATE_BACKBONES
@@ -48,17 +47,22 @@ class TemplateSKLearnClassifier(ClassificationTask):
     def __init__(
         self,
         num_features: int,
-        num_classes: int,
+        num_classes: Optional[int] = None,
+        labels: Optional[List[str]] = None,
         backbone: Union[str, Tuple[nn.Module, int]] = "mlp-128",
         backbone_kwargs: Optional[Dict] = None,
         loss_fn: LOSS_FN_TYPE = None,
         optimizer: OPTIMIZER_TYPE = "Adam",
         lr_scheduler: LR_SCHEDULER_TYPE = None,
         metrics: METRICS_TYPE = None,
-        learning_rate: float = 1e-2,
+        learning_rate: Optional[float] = None,
         multi_label: bool = False,
-        serializer: SERIALIZER_TYPE = None,
     ):
+        self.save_hyperparameters()
+
+        if labels is not None and num_classes is None:
+            num_classes = len(labels)
+
         super().__init__(
             model=None,
             loss_fn=loss_fn,
@@ -67,11 +71,10 @@ class TemplateSKLearnClassifier(ClassificationTask):
             metrics=metrics,
             learning_rate=learning_rate,
             multi_label=multi_label,
-            serializer=serializer or Labels(),
+            num_classes=num_classes,
+            labels=labels,
         )
 
-        self.save_hyperparameters()
-
         if not backbone_kwargs:
             backbone_kwargs = {}
 
@@ -83,30 +86,30 @@ class TemplateSKLearnClassifier(ClassificationTask):
         self.head = nn.Linear(out_features, num_classes)
 
     def training_step(self, batch: Any, batch_idx: int) -> Any:
-        """For the training step, we just extract the :attr:`~flash.core.data.data_source.DefaultDataKeys.INPUT` and
-        :attr:`~flash.core.data.data_source.DefaultDataKeys.TARGET` keys from the input and forward them to the
+        """For the training step, we just extract the :attr:`~flash.core.data.io.input.DataKeys.INPUT` and
+        :attr:`~flash.core.data.io.input.DataKeys.TARGET` keys from the input and forward them to the
         :meth:`~flash.core.model.Task.training_step`."""
-        batch = (batch[DefaultDataKeys.INPUT], batch[DefaultDataKeys.TARGET])
+        batch = (batch[DataKeys.INPUT], batch[DataKeys.TARGET])
         return super().training_step(batch, batch_idx)
 
     def validation_step(self, batch: Any, batch_idx: int) -> Any:
-        """For the validation step, we just extract the :attr:`~flash.core.data.data_source.DefaultDataKeys.INPUT` and
-        :attr:`~flash.core.data.data_source.DefaultDataKeys.TARGET` keys from the input and forward them to the
+        """For the validation step, we just extract the :attr:`~flash.core.data.io.input.DataKeys.INPUT` and
+        :attr:`~flash.core.data.io.input.DataKeys.TARGET` keys from the input and forward them to the
         :meth:`~flash.core.model.Task.validation_step`."""
-        batch = (batch[DefaultDataKeys.INPUT], batch[DefaultDataKeys.TARGET])
+        batch = (batch[DataKeys.INPUT], batch[DataKeys.TARGET])
         return super().validation_step(batch, batch_idx)
 
     def test_step(self, batch: Any, batch_idx: int) -> Any:
-        """For the test step, we just extract the :attr:`~flash.core.data.data_source.DefaultDataKeys.INPUT` and
-        :attr:`~flash.core.data.data_source.DefaultDataKeys.TARGET` keys from the input and forward them to the
+        """For the test step, we just extract the :attr:`~flash.core.data.io.input.DataKeys.INPUT` and
+        :attr:`~flash.core.data.io.input.DataKeys.TARGET` keys from the input and forward them to the
         :meth:`~flash.core.model.Task.test_step`."""
-        batch = (batch[DefaultDataKeys.INPUT], batch[DefaultDataKeys.TARGET])
+        batch = (batch[DataKeys.INPUT], batch[DataKeys.TARGET])
         return super().test_step(batch, batch_idx)
 
     def predict_step(self, batch: Any, batch_idx: int, dataloader_idx: int = 0) -> Any:
-        """For the predict step, we just extract the :attr:`~flash.core.data.data_source.DefaultDataKeys.INPUT` key
-        from the input and forward it to the :meth:`~flash.core.model.Task.predict_step`."""
-        batch = batch[DefaultDataKeys.INPUT]
+        """For the predict step, we just extract the :attr:`~flash.core.data.io.input.DataKeys.INPUT` key from the
+        input and forward it to the :meth:`~flash.core.model.Task.predict_step`."""
+        batch = batch[DataKeys.INPUT]
         return super().predict_step(batch, batch_idx, dataloader_idx=dataloader_idx)
 
     def forward(self, x) -> torch.Tensor:
