@@ -20,10 +20,9 @@ __all__ = ["translation"]
 
 
 def from_wmt_en_ro(
-    backbone: str = "Helsinki-NLP/opus-mt-en-ro",
     batch_size: int = 4,
     num_workers: int = 0,
-    **preprocess_kwargs,
+    **input_transform_kwargs,
 ) -> TranslationData:
     """Downloads and loads the WMT EN RO data set."""
     download_data("https://pl-flash-data.s3.amazonaws.com/wmt_en_ro.zip", "./data")
@@ -32,10 +31,9 @@ def from_wmt_en_ro(
         "target",
         train_file="data/wmt_en_ro/train.csv",
         val_file="data/wmt_en_ro/valid.csv",
-        backbone=backbone,
         batch_size=batch_size,
         num_workers=num_workers,
-        **preprocess_kwargs,
+        **input_transform_kwargs,
     )
 
 
